manatus: Metadata aggregation and transformation python library (backronym pending)
===================================================================================

Manatus is a python utility and library for harvesting and transforming the output of OAI-PMH aggregators and APIs into
`DPLA's MAP <https://pro.dp.la/hubs/metadata-application-profile>`_ JSON-LD.

Mantus is the species name of Florida's official marine mammal, the Florida Manatee, *Trichechus manatus latirostris*.

Dependencies
------------

* `pymods <https://github.com/mrmiguez/pymods>`_ v2.0.6 or greater
* `sickle <https://sickle.readthedocs.io/en/latest/>`_

Installation & Use
------------------

``python3 -m pip install manatus``

``python3 -m manatus``


Documentation
-------------

Full documentation is available at `Read the Docs <https://manatus.readthedocs.io>`_
